@@ -19,7 +19,7 @@ use Data::Dumper;
 use Math::Pari qw(PARI pari2pv Mod isprime lcm lift);
 use Carp;
 
-$Crypt::RSA::Key::Private::VERSION = '1.97'; 
+$Crypt::RSA::Key::Private::VERSION = '1.98'; 
 
 sub new { 
 
@@ -168,7 +168,7 @@ sub write {
     my ($self, %params) = @_; 
     $self->hide();
     my $string = $self->serialize (%params); 
-    open DISK, ">$params{Filename}" || 
+    open DISK, ">$params{Filename}" or
         croak "Can't open $params{Filename} for writing.";
     binmode DISK;
     print DISK $string;
